#!/usr/bin/env python
# encoding: utf-8

true_courses = [
    '.' , '..',
    'testcourse',
    'testcourse2',
    'testcourse3'
]

false_courses = [
    '.' , '..',
    'testcourse2',
    'testcourse3'
]